@@ -207,7 +207,10 @@ class IdentifierSchemes:
     API_GATEWAY_APPLICATION = IdentifierScheme(
         'application.api.apps.cam.ac.uk',
         'Application Gateway Application',
-        frozendict({})
+        frozendict({
+            'development': 'apigee-development.devel.api.gcp.uis.cam.ac.uk',
+            'staging': 'apigee-staging.test.api.gcp.uis.cam.ac.uk'
+        })
     )
 
     @staticmethod
