@@ -21,8 +21,7 @@ class PhotoClient (IdentityAPIClient):
         token_url: str = 'https://api.apps.cam.ac.uk/oauth/client_credential/accesstoken',
         config: Optional[Mapping] = {},
     ):
-
-        super(PhotoClient, self).__init__(
+        super().__init__(
             client_id, client_secret, base_url, token_url, config
         )
 
