@@ -2,6 +2,7 @@ from unittest import TestCase
 from base64 import b64encode
 from requests import exceptions, Session
 from requests_mock import Mocker
+from time import time
 from typing import Mapping, Optional
 
 from identitylib.card_client import CardClient
@@ -77,6 +78,8 @@ class CardAPITestMixin:
             json={
                 'token_type': 'Bearer',
                 'access_token': 'fake-token',
+                'expires_in': 3599,
+                'issued_at': time()
             }
         )
 
